(action-and-close action notification-type)Returns a function that calls a given action & fires a close event for a given notification type.
Returns a function that calls a given action & fires a close event for a given notification type.
(keywordize-str & vals)Like the str function, but will result in a keyword and can take strings or kewords as arguments
Like the str function, but will result in a keyword and can take strings or kewords as arguments
(pluralize-keyword k)Takes a keyword and adds an 's'.
Takes a keyword and adds an 's'.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |